@@ -163,12 +163,12 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 	{
 		WidgetParameters params;
 
-		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-
 		/* Override the entries state type, because we are too lame to handle this via
 		 * the focus ring, and GtkEntry doesn't even set the INSENSITIVE state ... */
 		if (state_type == GTK_STATE_NORMAL && widget && GE_IS_ENTRY (widget))
-			params.state_type = GTK_WIDGET_STATE (widget);
+			state_type = GTK_WIDGET_STATE (widget);
+
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
 		if (CHECK_HINT (GE_HINT_COMBOBOX_ENTRY) || CHECK_HINT (GE_HINT_SPINBUTTON))
 		{
@@ -645,7 +645,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		ScrollBarParameters scrollbar;
 
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		params.corners = CR_CORNER_NONE;
+		params.corners = CR_CORNER_ALL;
 
 		scrollbar.horizontal = TRUE;
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
@@ -1287,7 +1287,9 @@ clearlooks_style_realize (GtkStyle * style)
 
 	for (i = 0; i < 9; i++)
 	{
-		ge_shade_color (&bg_normal, (shades[i]-0.7) * contrast + 0.7, &clearlooks_style->colors.shade[i]);
+		ge_shade_color (&bg_normal, (shades[i] < 1.0) ?
+		                (shades[i]/contrast) : (shades[i]*contrast),
+		                &clearlooks_style->colors.shade[i]);
 	}
 
 	ge_gdk_color_to_cairo (&style->bg[GTK_STATE_SELECTED], &spot_color);
